bmatrix: Inline latex method for matrix

Description Usage Arguments Value See Also Examples

Description

Write R matrix object in Latex block. This function might be useful as an alternative to implementing the whole package. By this one function, same things can be done as knit_print.matrix, althogh you should specify the function.

Usage

1

Arguments

x

R matrix object

Value

This function is designed to use in the latex block. Output in the chunk might useless. For chunk usage, 'paste()' of last line should be replaced by 'writeLines()'.

See Also

knit_print.matrix

Examples

1
2
3
4
A <- matrix(1:9, nrow = 3)
bmatrix(A)
## You can write the matrix A in the inline $`r bmatrix(A)`$ or
## $$`r bmatrix(A)`$$

ygeunkim/rmdtool documentation built on July 1, 2019, 1:57 p.m.