Description Usage Value Examples
By writing this script at the beginning of the rmd file, equation referencing becomes more flexible in html documents.
1 |
Copy and paste to the document
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.