tab: Cross reference a table caption

Description Usage Format Value See Also Examples

Description

list, cross reference a table in r markdown with label and link of pdf

Usage

1

Format

An object of class list of length 2.

Value

Everything is same but Figure versus Table.

refer

of '$cap' refer the table caption, same as the chunk name

title

of '$cap' caption of the table

refer

of '$ref' cross refer the corresponding table by number

See Also

fig Figure numbering

Examples

1
2
3
knitr::kable(ggplot2::mpg, caption = tab$cap("tab-chunk-name", "Caption name"))
tab$ref("tab-chunk-name")
## For detailed usage, see the vignette

ygeunkim/rmdtool documentation built on July 1, 2019, 1:57 p.m.