Description Usage Arguments Value See Also Examples
Write R matrix object in Latex block.
This function might be useful as an alternative to implementing the whole package.
By this one function, same things can be done as knit_print.matrix, althogh you should specify the function.
1 | bmatrix(x)
|
x |
R matrix object |
This function is designed to use in the latex block. Output in the chunk might useless. For chunk usage, 'paste()' of last line should be replaced by 'writeLines()'.
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.