Description Usage Format Value See Also Examples
list, cross reference a 'fig.cap' in r markdown with label and link of pdf
1 |
An object of class list of length 2.
The number of the figure increases in order. fig$ref("chunk") returns the figure number followed by the string Figure. You don't have to worry changed order of plots while documentation. Also, they provide hyperlink in pdf document so that you can easily approach the plots.
refer |
of '$cap' refer the figure caption, same as the chunk name |
title |
of '$cap' caption of the plot |
refer |
of '$ref' cross refer the corresponding figure by number |
tab Table numbering
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.