Description Usage Arguments See Also Examples
‘knitr_print()' will print an object with math form in the r markdown chunk or inline. It can be an tex or a matrix. In the chunk, 'results = ’asis'' option should be assigned to that chunk. Printing matrix becomes more compact than before. It will be printed math form in the inline, i.e. 'r matrix'. Here, the function does not have to be written. If in-chunk option is choosed, normal matrix form in R console will be printed.
1 2 3 4 5 |
x |
'tex' or 'matrix' to be printed |
inline |
Choose between inline versus in-chunk. The default is set to be 'inline = FALSE', in-chunk. |
... |
Additional arguments passed to the S3 method. |
bmatrix Printing matrix latex form by using the function
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.