Description Usage Format Value See Also Examples
list, cross reference a table in r markdown with label and link of pdf
1 |
An object of class list of length 2.
Everything is same but Figure versus Table.
refer |
of '$cap' refer the table caption, same as the chunk name |
title |
of '$cap' caption of the table |
refer |
of '$ref' cross refer the corresponding table by number |
fig Figure numbering
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.